@@ -17,7 +17,7 @@ use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.7.1';
+use version; our $VERSION = 'v0.8.0';
 
 my $PROGRAM = basename $0;
 
@@ -245,10 +245,13 @@ sub _retrieve {
         print "Not found - @keys\n";
         return 1;
     }
+    if (@$items == 1) {
+        $items->[0]->output;
+        return 1;
+    }
     for (my $i=0; $i < scalar(@$items); $i++) {
         my $item = $items->[$i];
-        print $item->output;
-        printf "%s\n", '-' x 24 if ($i < scalar(@$items) - 1);
+        $item->output_line;
     }
     return 1;
 }
@@ -381,13 +384,24 @@ sub cachedump {
         return;
     }
     my $response = $self->{ds}->query("stats cachedump $class $num");
+    my %expires;
     for my $line (@$response) {
         if ($line !~ m/^ITEM (\S+) \[(\d+) b; (\d+) s\]/) {
             warn "Unknown response: $line";
             next;
         }
         my %data = (key => $1, length => $2, expire => $3);
-        my $item = App::Memcached::CLI::Item->new(%data);
+        $expires{$data{key}} = \%data;
+    }
+    return 1 unless %expires;
+
+    my @keys = keys %expires;
+    my $items = App::Memcached::CLI::Item->find(
+        \@keys, $self->{ds}, command => 'gets',
+    );
+    for (my $i=0; $i < scalar(@$items); $i++) {
+        my $item = $items->[$i];
+        $item->{expire} = $expires{$item->{key}}{expire};
         $item->output_line;
     }
     return 1;
